@@ -9,10 +9,16 @@ from finstmt.config_manage.statements import StatementsConfigManager
 from finstmt.inc.config import INCOME_STATEMENT_INPUT_ITEMS
 
 inc_data_config_mgr = DataConfigManager(INCOME_STATEMENT_INPUT_ITEMS)
-inc_stmt_config_mgr = StatementConfigManager({pd.Timestamp(datetime.datetime.today()): inc_data_config_mgr})
+inc_stmt_config_mgr = StatementConfigManager(
+    {pd.Timestamp(datetime.datetime.today()): inc_data_config_mgr}
+)
 bs_data_config_mgr = DataConfigManager(BALANCE_SHEET_INPUT_ITEMS)
-bs_stmt_config_mgr = StatementConfigManager({pd.Timestamp(datetime.datetime.today()): bs_data_config_mgr})
-CONFIG = StatementsConfigManager(config_managers={
-    'income_statements': inc_stmt_config_mgr,
-    'balance_sheets': bs_stmt_config_mgr
-})
\ No newline at end of file
+bs_stmt_config_mgr = StatementConfigManager(
+    {pd.Timestamp(datetime.datetime.today()): bs_data_config_mgr}
+)
+CONFIG = StatementsConfigManager(
+    config_managers={
+        "income_statements": inc_stmt_config_mgr,
+        "balance_sheets": bs_stmt_config_mgr,
+    }
+)
