@@ -26,6 +26,24 @@ class StatementsConfigManager(ConfigManagerBase):
         config, _ = self._get(item_key)
         return config
 
+    def __getattr__(self, item_key: str) -> ItemConfig:
+        """
+        Get the config for a given key
+        """
+        # When copying the object, config_managers can be undefined and so would cause a
+        # recursive loop without this check
+        if item_key == "config_managers":
+            # Trigger the default Python behavior
+            return object.__getattribute__(self, item_key)
+
+        try:
+            return self.get(item_key)
+        except NoSuchItemException:
+            raise AttributeError(item_key)
+
+    def __dir__(self) -> List[str]:
+        return self.keys
+
     def _get(self, item_key: str) -> Tuple[ItemConfig, str]:
         """
         For internal use, get the config as well as the key of the financial statement type it belongs to
